@@ -9,7 +9,7 @@ package DateTime::Format::RFC3339;
 
 
 BEGIN {
-   use version; our $VERSION = qv('1.0.0');
+   use version; our $VERSION = qv('1.0.1');
 }
 
 
@@ -101,7 +101,7 @@ DateTime::Format::RFC3339 - Parse and format RFC3339 datetime strings
 
 =head1 VERSION
 
-Version 1.0.0
+Version 1.0.1
 
 
 =head1 SYNOPSIS
@@ -112,13 +112,13 @@ Version 1.0.0
     my $dt = $f->parse_datetime( '2002-07-01T13:50:05Z' );
 
     # 2002-07-01T13:50:05Z
-    $f->format_datetime($dt);
+    print $f->format_datetime($dt);
 
 
 =head1 DESCRIPTION
 
 This module understands the RFC3339 date/time format, an ISO 8601 profile,
-defined at L<http://www.ietf.org/rfc/rfc3339.txt>.
+defined at L<http://tools.ietf.org/html/rfc3339>.
 
 It can be used to parse these formats in order to create the appropriate 
 objects.
@@ -128,7 +128,7 @@ objects.
 
 =over
 
-=item parse_datetime($string)
+=item C<parse_datetime($string)>
 
 Given a RFC3339 datetime string, this method will return a new
 L<DateTime> object.
@@ -137,7 +137,7 @@ If given an improperly formatted string, this method will croak.
 
 For a more flexible parser, see L<DateTime::Format::ISO8601>.
 
-=item format_datetime($datetime)
+=item C<format_datetime($datetime)>
 
 Given a L<DateTime> object, this methods returns a RFC3339 datetime
 string.
@@ -155,6 +155,7 @@ For simplicity, the datetime will be converted to UTC first.
 =item * L<DateTime::Format::ISO8601>
 
 =item * L<http://tools.ietf.org/html/rfc3339>, "Date and Time on the Internet: Timestamps"
+
 =back
 
 
